==> axiom-1.4.0-src.zip: axiom-1.4.0/components/core-streams/src/main/java/org/apache/axiom/core/stream/stax/pull/input/StAXPullInput.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.axiom.core.stream.stax.pull.input;

import java.io.Closeable;

import javax.xml.stream.XMLStreamReader;

import org.apache.axiom.core.stream.XmlHandler;
import org.apache.axiom.core.stream.XmlInput;
import org.apache.axiom.core.stream.XmlReader;

public final class StAXPullInput implements XmlInput {
    private final XMLStreamReader reader;
    private final XMLStreamReaderHelperFactory helperFactory;
    private final boolean autoClose;
    private final Closeable closeable;
    
    public StAXPullInput(XMLStreamReader reader, XMLStreamReaderHelperFactory helperFactory, boolean autoClose, Closeable closeable) {
        this.reader = reader;
        this.helperFactory = helperFactory;
        this.autoClose = autoClose;
        this.closeable = closeable;
    }

    public StAXPullInput(XMLStreamReader reader, XMLStreamReaderHelperFactory helperFactory) {
        this(reader, helperFactory, true, null);
    }

    @Override
    public XmlReader createReader(XmlHandler handler) {
        return new StAXPullReader(reader, helperFactory.createHelper(reader), handler, closeable, autoClose);
    }
}

==> axiom-2.0.0-src.zip: axiom-2.0.0/components/core-streams/src/main/java/org/apache/axiom/core/stream/stax/pull/input/StAXPullInput.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.axiom.core.stream.stax.pull.input;

import java.io.Closeable;

import javax.xml.stream.XMLStreamReader;

import org.apache.axiom.core.stream.XmlHandler;
import org.apache.axiom.core.stream.XmlInput;
import org.apache.axiom.core.stream.XmlReader;

public final class StAXPullInput implements XmlInput {
    private final XMLStreamReader reader;
    private final XMLStreamReaderHelperFactory helperFactory;
    private final boolean autoClose;
    private final Closeable closeable;

    public StAXPullInput(
            XMLStreamReader reader,
            XMLStreamReaderHelperFactory helperFactory,
            boolean autoClose,
            Closeable closeable) {
        this.reader = reader;
        this.helperFactory = helperFactory;
        this.autoClose = autoClose;
        this.closeable = closeable;
    }

    public StAXPullInput(XMLStreamReader reader, XMLStreamReaderHelperFactory helperFactory) {
        this(reader, helperFactory, true, null);
    }

    @Override
    public XmlReader createReader(XmlHandler handler) {
        return new StAXPullReader(
                reader, helperFactory.createHelper(reader), handler, closeable, autoClose);
    }
}
